==> testspeednet-1.0.1-py3-none-any.whl: testspeednet/__init__.py <==
# -*- coding: UTF-8 -*-

'''
Module
    __init__.py
Copyright
    Copyright (C) 2016 - 2024 Vladimir Roncevic <elektron.ronca@gmail.com>
    testspeednet is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by the
    Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.
    testspeednet is distributed in the hope that it will be useful, but
    WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
    See the GNU General Public License for more details.
    You should have received a copy of the GNU General Public License along
    with this program. If not, see <http://www.gnu.org/licenses/>.
Info
    Defines class TestSpeedNet with attribute(s) and method(s).
    Loads a base info, creates a CLI interface and run operation(s).
'''

import sys
from typing import List, Dict
from os.path import dirname, realpath
from argparse import Namespace

try:
    from ats_utilities.splash import Splash
    from ats_utilities.logging import ATSLogger
    from ats_utilities.cli.cfg_cli import CfgCLI
    from ats_utilities.console_io.error import error_message
    from ats_utilities.console_io.verbose import verbose_message
    from ats_utilities.console_io.success import success_message
    from ats_utilities.exceptions.ats_type_error import ATSTypeError
    from ats_utilities.exceptions.ats_value_error import ATSValueError
    from testspeednet.net import TestSpeedNetProcessor
except ImportError as ats_error_message:
    # Force close python ATS ##################################################
    sys.exit(f'\n{__file__}\n{ats_error_message}\n')

__author__ = 'Vladimir Roncevic'
__copyright__ = '(C) 2024, https://vroncevic.github.io/testspeednet'
__credits__: List[str] = ['Vladimir Roncevic', 'Python Software Foundation']
__license__ = 'https://github.com/vroncevic/testspeednet/blob/dev/LICENSE'
__version__ = '1.0.1'
__maintainer__ = 'Vladimir Roncevic'
__email__ = 'elektron.ronca@gmail.com'
__status__ = 'Updated'


class TestSpeedNet(CfgCLI):
    '''
        Defines class TestSpeedNet with attribute(s) and method(s).
        Loads a base info, creates a CLI interface and run operation(s).

        It defines:

            :attributes:
                | _TOOL_VERBOSE - Console text indicator for process-phase.
                | _CONFIG - Tool info file path.
                | _LOG - Tool log file path.
                | _LOGO - Logo for splash screen.
                | _OPS - List of tool options.
                | _logger - Logger object API.
            :methods:
                | __init__ - Initials TestSpeedNet constructor.
                | process - Processes and runs operations.
    '''

    _TOOL_VERBOSE: str = 'TEST_SPEED_NET'
    _CONFIG: str = '/conf/testspeednet.cfg'
    _LOG: str = '/log/testspeednet.log'
    _LOGO: str = '/conf/testspeednet.logo'
    _OPS: List[str] = ['-c', '--cmd', '-v', '--verbose']

    def __init__(self, verbose: bool = False) -> None:
        '''
            Initials TestSpeedNet constructor.

            :param verbose: Enable/Disable verbose option
            :type verbose: <bool>
            :exceptions: None
        '''
        current_dir: str = dirname(realpath(__file__))
        testspeednet_property: Dict[str, str | bool] = {
            'ats_organization': 'vroncevic',
            'ats_repository': f'{self._TOOL_VERBOSE.lower()}',
            'ats_name': f'{self._TOOL_VERBOSE.lower()}',
            'ats_logo_path': f'{current_dir}{self._LOGO}',
            'ats_use_github_infrastructure': True
        }
        Splash(testspeednet_property, verbose)
        base_info: str = f'{current_dir}{self._CONFIG}'
        super().__init__(base_info, verbose)
        verbose_message(
            verbose, [f'{self._TOOL_VERBOSE.lower()} init tool info']
        )
        self._logger: ATSLogger = ATSLogger(
            self._TOOL_VERBOSE.lower(), f'{current_dir}{self._LOG}', verbose
        )
        if self.tool_operational:
            self.add_new_option(
                self._OPS[0], self._OPS[1], type=str,
                choices=['speed', 'download', 'upload', 'fetch'],
                required=True,
                help='check net speed (download/upload)'
            )
            self.add_new_option(
                self._OPS[2], self._OPS[3],
                action='store_true', default=False,
                help='activate verbose mode for generation'
            )

    def process(self, verbose: bool = False) -> bool:
        '''
            Processes and runs operations.

            :param verbose: Enable/Disable verbose option
            :type verbose: <bool>
            :return: True (success operation) | False
            :rtype: <bool>
            :exceptions: None
        '''
        status: bool = False
        if self.tool_operational:
            try:
                args: Namespace = self.parse_args(sys.argv)
                tool: TestSpeedNetProcessor = TestSpeedNetProcessor(
                    getattr(args, 'verbose') or verbose
                )
                try:
                    command: str | None = None
                    match args:
                        case Namespace(cmd='speed'):
                            command = getattr(args, 'cmd')
                        case Namespace(cmd='download'):
                            command = getattr(args, 'cmd')
                        case Namespace(cmd='upload'):
                            command = getattr(args, 'cmd')
                        case Namespace(cmd='fetch'):
                            command = getattr(args, 'cmd')
                        case _:
                            error_message(
                                [
                                    f'{self._TOOL_VERBOSE.lower()}',
                                    'missing tool argument'
                                ]
                            )
                    if bool(command):
                        status = tool.execute(
                            command, getattr(args, 'verbose') or verbose
                        )
                except (ATSTypeError, ATSValueError) as e:
                    error_message([f'{self._TOOL_VERBOSE.lower()} {str(e)}'])
                    self._logger.write_log(f'{str(e)}', self._logger.ATS_ERROR)
                if status:
                    success_message([f'{self._TOOL_VERBOSE.lower()} done\n'])
                    self._logger.write_log(
                        'execute command done', self._logger.ATS_INFO
                    )
                else:
                    error_message([f'{self._TOOL_VERBOSE.lower()} failed'])
                    self._logger.write_log(
                        'execute command failed', self._logger.ATS_ERROR
                    )
            except SystemExit:
                error_message(
                    [f'{self._TOOL_VERBOSE.lower()} expected argument -n']
                )
                return status
        else:
            error_message(
                [f'{self._TOOL_VERBOSE.lower()} tool is not operational']
            )
            self._logger.write_log(
                'tool is not operational', self._logger.ATS_ERROR
            )
        return status

==> testspeednet-1.0.2-py3-none-any.whl: testspeednet/__init__.py <==
# -*- coding: UTF-8 -*-

'''
Module
    __init__.py
Copyright
    Copyright (C) 2016 - 2024 Vladimir Roncevic <elektron.ronca@gmail.com>
    testspeednet is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by the
    Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.
    testspeednet is distributed in the hope that it will be useful, but
    WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
    See the GNU General Public License for more details.
    You should have received a copy of the GNU General Public License along
    with this program. If not, see <http://www.gnu.org/licenses/>.
Info
    Defines class TestSpeedNet with attribute(s) and method(s).
    Loads a base info, creates a CLI interface and run operation(s).
'''

import sys
from typing import List, Dict, Optional
from os.path import dirname, realpath
from argparse import Namespace

try:
    from ats_utilities.splash import Splash
    from ats_utilities.logging import ATSLogger
    from ats_utilities.cli import ATSCli
    from ats_utilities.console_io.error import error_message
    from ats_utilities.console_io.verbose import verbose_message
    from ats_utilities.console_io.success import success_message
    from ats_utilities.exceptions.ats_type_error import ATSTypeError
    from ats_utilities.exceptions.ats_value_error import ATSValueError
    from testspeednet.net import TestSpeedNetProcessor
except ImportError as ats_error_message:
    # Force close python ATS ##################################################
    sys.exit(f'\n{__file__}\n{ats_error_message}\n')

__author__ = 'Vladimir Roncevic'
__copyright__ = '(C) 2024, https://vroncevic.github.io/testspeednet'
__credits__: List[str] = ['Vladimir Roncevic', 'Python Software Foundation']
__license__ = 'https://github.com/vroncevic/testspeednet/blob/dev/LICENSE'
__version__ = '1.0.2'
__maintainer__ = 'Vladimir Roncevic'
__email__ = 'elektron.ronca@gmail.com'
__status__ = 'Updated'


class TestSpeedNet(ATSCli):
    '''
        Defines class TestSpeedNet with attribute(s) and method(s).
        Loads a base info, creates a CLI interface and run operation(s).

        It defines:

            :attributes:
                | _TOOL_VERBOSE - Console text indicator for process-phase.
                | _CONFIG - Tool info file path.
                | _LOG - Tool log file path.
                | _LOGO - Logo for splash screen.
                | _OPS - List of tool options.
                | _logger - Logger object API.
            :methods:
                | __init__ - Initials TestSpeedNet constructor.
                | process - Processes and runs operations.
    '''

    _TOOL_VERBOSE: str = 'TEST_SPEED_NET'
    _CONFIG: str = '/conf/testspeednet.cfg'
    _LOG: str = '/log/testspeednet.log'
    _LOGO: str = '/conf/testspeednet.logo'
    _OPS: List[str] = ['-c', '--cmd', '-v', '--verbose']

    def __init__(self, verbose: bool = False) -> None:
        '''
            Initials TestSpeedNet constructor.

            :param verbose: Enable/Disable verbose option
            :type verbose: <bool>
            :exceptions: None
        '''
        current_dir: str = dirname(realpath(__file__))
        testspeednet_property: Dict[str, str | bool] = {
            'ats_organization': 'vroncevic',
            'ats_repository': f'{self._TOOL_VERBOSE.lower()}',
            'ats_name': f'{self._TOOL_VERBOSE.lower()}',
            'ats_logo_path': f'{current_dir}{self._LOGO}',
            'ats_use_github_infrastructure': True
        }
        Splash(testspeednet_property, verbose)
        base_info: str = f'{current_dir}{self._CONFIG}'
        super().__init__(base_info, verbose)
        verbose_message(
            verbose, [f'{self._TOOL_VERBOSE.lower()} init tool info']
        )
        self._logger: ATSLogger = ATSLogger(
            self._TOOL_VERBOSE.lower(), True, None, True, verbose
        )
        if self.is_operational():
            self.add_new_option(
                self._OPS[0], self._OPS[1], type=str,
                choices=['speed', 'download', 'upload', 'fetch'],
                required=True,
                help='check net speed (download/upload)'
            )
            self.add_new_option(
                self._OPS[2], self._OPS[3],
                action='store_true', default=False,
                help='activate verbose mode for generation'
            )

    def process(self, verbose: bool = False) -> bool:
        '''
            Processes and runs operations.

            :param verbose: Enable/Disable verbose option
            :type verbose: <bool>
            :return: True (success operation) | False
            :rtype: <bool>
            :exceptions: None
        '''
        status: bool = False
        if self.is_operational():
            try:
                args: Optional[Namespace] = self.parse_args(sys.argv)
                tool: TestSpeedNetProcessor = TestSpeedNetProcessor(
                    getattr(args, 'verbose') or verbose
                )
                try:
                    command: Optional[str] = None
                    match args:
                        case Namespace(cmd='speed'):
                            command = getattr(args, 'cmd')
                        case Namespace(cmd='download'):
                            command = getattr(args, 'cmd')
                        case Namespace(cmd='upload'):
                            command = getattr(args, 'cmd')
                        case Namespace(cmd='fetch'):
                            command = getattr(args, 'cmd')
                        case _:
                            error_message(
                                [
                                    f'{self._TOOL_VERBOSE.lower()}',
                                    'missing tool argument'
                                ]
                            )
                    if bool(command):
                        status = tool.execute(
                            command, getattr(args, 'verbose') or verbose
                        )
                except (ATSTypeError, ATSValueError) as e:
                    error_message([f'{self._TOOL_VERBOSE.lower()} {str(e)}'])
                    self._logger.write_log(f'{str(e)}', self._logger.ATS_ERROR)
                if status:
                    success_message([f'{self._TOOL_VERBOSE.lower()} done\n'])
                    self._logger.write_log(
                        'execute command done', self._logger.ATS_INFO
                    )
                else:
                    error_message([f'{self._TOOL_VERBOSE.lower()} failed'])
                    self._logger.write_log(
                        'execute command failed', self._logger.ATS_ERROR
                    )
            except SystemExit:
                error_message(
                    [f'{self._TOOL_VERBOSE.lower()} expected argument cmd']
                )
                return status
        else:
            error_message(
                [f'{self._TOOL_VERBOSE.lower()} tool is not operational']
            )
            self._logger.write_log(
                'tool is not operational', self._logger.ATS_ERROR
            )
        return status
